@@ -15,9 +15,6 @@ class TestSlimCommands < Minitest::Test
   # exception raising example
   EXCEPTION_TEMPLATE = '- raise NotImplementedError'
 
-  # Temple has this feature...
-  STRING_FREEZER = RUBY_VERSION >= '2.1' ? '.freeze' : ''
-
   def test_option_help
     out, err = exec_slimrb '--help'
 
@@ -43,7 +40,7 @@ class TestSlimCommands < Minitest::Test
   def test_compile
     prepare_common_test STATIC_TEMPLATE, '--compile' do |out, err|
       assert err.empty?
-      assert_match %r{\"<p>Hello World!<\/p>\"#{STRING_FREEZER}}, out
+      assert_match %r{\"<p>Hello World!<\/p>\".freeze}, out
     end
   end
 
@@ -58,10 +55,14 @@ class TestSlimCommands < Minitest::Test
     prepare_common_test DYNAMIC_TEMPLATE, '--rails' do |out, err|
       assert err.empty?
 
-      assert out.include? %Q{@output_buffer = ActiveSupport::SafeBuffer.new;}
-      assert out.include? %Q{@output_buffer.safe_concat(("<p>Hello "#{STRING_FREEZER}));}
+      if Gem::Version.new(Temple::VERSION) >= Gem::Version.new('0.9')
+        assert out.include? %Q{@output_buffer = output_buffer || ActionView::OutputBuffer.new;}
+      else
+        assert out.include? %Q{@output_buffer = ActiveSupport::SafeBuffer.new;}
+      end
+      assert out.include? %Q{@output_buffer.safe_concat(("<p>Hello ".freeze));}
       assert out.include? %Q{@output_buffer.safe_concat(((::Temple::Utils.escape_html((name))).to_s));}
-      assert out.include? %Q{@output_buffer.safe_concat(("!</p>"#{STRING_FREEZER}));}
+      assert out.include? %Q{@output_buffer.safe_concat(("!</p>".freeze));}
     end
   end
 
@@ -72,23 +73,19 @@ class TestSlimCommands < Minitest::Test
     end
   end
 
-  # We cannot run these two on Travis, because we can't install libyaml.
-  # See https://github.com/slim-template/slim/issues/576
-  if ENV['TRAVIS'] && RUBY_ENGINE != 'rbx'
-    def test_locals_json
-      data = '{"name":"from slim"}'
-      prepare_common_test DYNAMIC_TEMPLATE, '--locals', data do |out, err|
-        assert err.empty?
-        assert_equal "<p>Hello from slim!</p>\n", out
-      end
+  def test_locals_json
+    data = '{"name":"from slim"}'
+    prepare_common_test DYNAMIC_TEMPLATE, '--locals', data do |out, err|
+      assert err.empty?
+      assert_equal "<p>Hello from slim!</p>\n", out
     end
+  end
 
-    def test_locals_yaml
-      data = "name: from slim"
-      prepare_common_test DYNAMIC_TEMPLATE, '--locals', data do |out, err|
-        assert err.empty?
-        assert_equal "<p>Hello from slim!</p>\n", out
-      end
+  def test_locals_yaml
+    data = "name: from slim"
+    prepare_common_test DYNAMIC_TEMPLATE, '--locals', data do |out, err|
+      assert err.empty?
+      assert_equal "<p>Hello from slim!</p>\n", out
     end
   end
 
