@@ -2,11 +2,12 @@ require 'helper'
 
 class TestSlimPretty < TestSlim
   def setup
-    Slim::Engine.set_default_options :pretty => true
+    super
+    Slim::Engine.set_options pretty: true
   end
 
   def teardown
-    Slim::Engine.set_default_options :pretty => false
+    Slim::Engine.set_options pretty: false
   end
 
   def test_pretty
@@ -28,9 +29,8 @@ html
     /[if lt IE 9]
       script src="old-ie1.js"
       script src="old-ie2.js"
-    sass:
-      body
-        background-color: red
+    css:
+      body { background-color: red; }
   body
     #container
       p Hello
@@ -55,10 +55,8 @@ html
     <script src="old-ie1.js"></script>
     <script src="old-ie2.js"></script>
     <![endif]-->
-    <style type="text/css">
-      body {
-        background-color: red;
-      }
+    <style>
+      body { background-color: red; }
     </style>
   </head>
   <body>
@@ -86,7 +84,7 @@ html
   | content}
 
     source = %q{html
-  == render body, :scope => self, :locals => { :content => content }}
+  == render body, scope: self, locals: { content: content }}
 
     result = %q{<html>
   <body>
@@ -96,6 +94,70 @@ html
   </body>
 </html>}
 
-    assert_html result, source, :scope => self, :locals => {:body => body, :content => content }
+    assert_html result, source, scope: self, locals: {body: body, content: content }
+  end
+
+  def test_correct_line_number
+    source = %q{
+html
+  head
+  body
+    p Slim
+    = ''
+    = ''
+    = ''
+    = unknown_ruby_method
+}
+
+    assert_ruby_error NameError,"(__TEMPLATE__):9", source
+  end
+
+  def test_unindenting
+    source = %q{
+span before
+span = " middle "
+span after
+}
+
+    result = %q{<span>before</span><span> middle </span><span>after</span>}
+
+    assert_html result, source
+
+    source = %q{
+html
+  body == "  <div>\n    <a>link</a>\n  </div>"
+}
+
+    result = %q{<html>
+  <body>
+    <div>
+      <a>link</a>
+    </div>
+  </body>
+</html>}
+    assert_html result, source
+  end
+
+  def test_helper_unindent
+    source = %q{
+= define_macro :content
+     div
+      a link
+html
+  body
+   == call_macro :content
+}
+
+    result = %q{
+
+<html>
+  <body>
+    <div>
+      <a>link</a>
+    </div>
+  </body>
+</html>}
+
+    assert_html result, source
   end
 end
