@@ -6,7 +6,7 @@ class SlimController < ApplicationController
   end
 
   def no_layout
-    render :layout => false
+    render layout: false
   end
 
   def variables
@@ -18,7 +18,7 @@ class SlimController < ApplicationController
 
   def streaming
     @hello = "Hello Streaming!"
-    render :content_for, :stream => true
+    render :content_for, stream: true
   end
 
   def integers
@@ -26,12 +26,21 @@ class SlimController < ApplicationController
   end
 
   def thread_options
-    Slim::Engine.with_options(:shortcut => {'@' => { :attr => params[:attr] }}) do
+    default_shortcut = {'#' => {attr: 'id'}, '.' => {attr: 'class'} }
+    Slim::Engine.with_options(shortcut: default_shortcut.merge({'@' => { attr: params[:attr] }})) do
       render
     end
   end
 
+  def variant
+    request.variant = :testvariant
+    render :normal
+  end
+
   def content_for
     @hello = "Hello Slim!"
   end
+
+  def helper
+  end
 end
